@@ -8,6 +8,12 @@ def test_pbf():
     return pbf_path
 
 
+@pytest.fixture
+def helsinki_pbf():
+    pbf_path = get_path("helsinki_pbf")
+    return pbf_path
+
+
 @pytest.fixture
 def test_output_dir():
     import os, tempfile
@@ -195,4 +201,23 @@ def test_passing_incorrect_bounding_box(test_pbf):
         raise e
 
 
+def test_reading_network_from_area_without_data(helsinki_pbf):
+    from pyrosm import OSM
+    from geopandas import GeoDataFrame
+
+    # Bounding box for area that does not have any data
+    bbox = [24.940514, 60.173849, 24.942, 60.175892]
+
+    osm = OSM(filepath=helsinki_pbf, bounding_box=bbox)
+
+    # The tool should warn if no buildings were found
+    with pytest.warns(UserWarning) as w:
+        gdf = osm.get_network()
+        # Check the warning text
+        if "could not find any network data" in str(w):
+            pass
+
+    # Result should be empty GeoDataFrame
+    assert isinstance(gdf, GeoDataFrame)
+    assert gdf.shape == (0, 0)
 
